% MATLAB script for plotting Ladakh velocity models.
% (This will create a simplified version of Figure 3 from
%  the Caldwell et al. 2009 Tectonophysics paper.)
%
% Warren Caldwell, 30 June 2010, warrenc@stanford.edu
%
models=dir('*vel');              % create list of velocity files
figure(1)
for i=1:length(models)           % Loop over models
    mod=dlmread(models(i).name); % Read in model
    for j=1:length(mod)          % Loop through depth
        % Plot vertical segments:
        x=[mod(j,5) mod(j,5)];    % Velocity constant (4=P, 5=S)
        y=[mod(j,1) mod(j,2)];    % Depth step
        subplot(2,5,i), plot(x,y) % plot
        hold on
        if j<length(mod)         % no horizontal step at end
            % Plot horizontal segments:
            x=[mod(j,5) mod(j+1,5)];  % Velocity step (4=P, 5=S)
            y=[mod(j,2) mod(j,2)];    % Depth constant
            subplot(2,5,i), plot(x,y) % plot
        end
        set(gca,'YDir','reverse','XLim',[2.8 4.2]);
        title(models(i).name)
        %xlabel('Vel [km/s]'); ylabel('Depth [km]')
    end
    
end
